
def read(*requirements_file_paths: str):
    """Extract list of individual requirements from a 'requirements.txt' file

    Args:
        requirements_file_paths (Iterable[str]): Requirements file path

    Returns:
        [set[str]]: Individual requirements.
    """
    # TODO: Error "descriptor 'union' for 'set' objects
    # doesn't apply to a 'filter' object"
    return set.union(
        *[
            filter(
                lambda line: not line.startswith('#'),
                map(
                    str.strip,
                    open(file_path).readlines()
                )
            )
            for file_path in requirements_file_paths
        ]
    )



import logging

# Various Helper enums, instead of "magic" strings.


class Reader:
    """Redis Gears Reader Types"""
    KeysReader = "KeysReader"
    KeysOnlyReader = "KeysOnlyReader"
    StreamReader = "StreamReader"
    PythonReader = "PythonReader"
    ShardsIDReader = "ShardsIDReader"
    CommandReader = "CommandReader"


class TriggerMode:
    """Redis Geears Trigger modes for registered actions"""
    Async = 'async'
    AsyncLocal = 'async_local'
    Sync = 'sync'


class LogLevel:
    """Redis Gears log levels"""
    Debug = 'debug'
    Verbose = 'verbose'
    Notice = 'notice'
    Warning = 'warninig'

    @staticmethod
    def to_logging_level(rg_log_level):
        if rg_log_level == LogLevel.Debug:
            return logging.DEBUG
        elif rg_log_level == LogLevel.Verbose:
            return logging.INFO
        elif rg_log_level == LogLevel.Notice:
            return logging.WARNING
        elif rg_log_level == LogLevel.Warning:
            return logging.ERROR  # Maybe a little unintuitive ;)
        else:
            return logging.INFO



#!/usr/bin/env python
# -*- encoding: utf-8 -*-

import setuptools
import pathlib

here = pathlib.Path(__file__).parent.resolve()


def text(*names, encoding='utf8'):
    return here.joinpath(*names).read_text(encoding=encoding)


setuptools.setup(
    name="redgrease",
    version="0.0.13",
    license="MIT License",
    description="RedisGears helper package",
    long_description=text("README.md"),
    long_description_content_type="text/markdown",

    author="Anders Åström",
    author_email="anders@lyngon.com",
    url="https://github.com/lyngon/redgrease",

    packages=setuptools.find_packages(where='src'),
    package_dir={'': 'src'},

    classifiers=[  # https://pypi.org/classifiers/
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Topic :: Database",
        "Topic :: Software Development",
        "Topic :: Software Development :: Libraries :: Application Frameworks",
    ],
    install_requires=[
        'redis',
        'attrs',
    ],
    extras_requires=[],
    setup_requires=[],
    python_requires='>=3.6',
    keywords="Redis, Gears, development"
)



from typing import Callable, Any, Iterable, TypeVar, Union

# Type aliases for type hints

T = TypeVar('T')
Key = str
Record = dict
Callback = Callable[[Record], Any]
Extractor = Callable[[Record], T]
Mapper = Callable[[Record], Record]
Expander = Callable[[Record], Iterable[Record]]
Processor = Callable[[Record], None]
Filterer = Callable[[Record], bool]
Accumulator = Callable[[T, Record], T]
Reducer = Callable[[Key, T, Record], T]
BatchReducer = Callable[[Key, Iterable[Record]], T]
